@@ -435,6 +435,7 @@ class Network(
         *,
         subnets: typing.Sequence[ISubnetsProps],
         vpc: typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]],
+        nat_eip_allocation_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
         peering_configs: typing.Optional[typing.Mapping[builtins.str, typing.Union["PeeringConfig", typing.Dict[builtins.str, typing.Any]]]] = None,
     ) -> None:
         '''
@@ -442,13 +443,19 @@ class Network(
         :param id: -
         :param subnets: 
         :param vpc: 
+        :param nat_eip_allocation_ids: 
         :param peering_configs: 
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__df3f88ed1cc891dbd636f210624927d010c33ac961e6f577806e2dd937c456be)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
-        props = VPCProps(subnets=subnets, vpc=vpc, peering_configs=peering_configs)
+        props = VPCProps(
+            subnets=subnets,
+            vpc=vpc,
+            nat_eip_allocation_ids=nat_eip_allocation_ids,
+            peering_configs=peering_configs,
+        )
 
         jsii.create(self.__class__, self, [scope, id, props])
 
@@ -687,6 +694,7 @@ class PeeringConnectionInternalType:
     name_mapping={
         "subnets": "subnets",
         "vpc": "vpc",
+        "nat_eip_allocation_ids": "natEipAllocationIds",
         "peering_configs": "peeringConfigs",
     },
 )
@@ -696,11 +704,13 @@ class VPCProps:
         *,
         subnets: typing.Sequence[ISubnetsProps],
         vpc: typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]],
+        nat_eip_allocation_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
         peering_configs: typing.Optional[typing.Mapping[builtins.str, typing.Union[PeeringConfig, typing.Dict[builtins.str, typing.Any]]]] = None,
     ) -> None:
         '''
         :param subnets: 
         :param vpc: 
+        :param nat_eip_allocation_ids: 
         :param peering_configs: 
         '''
         if isinstance(vpc, dict):
@@ -709,11 +719,14 @@ class VPCProps:
             type_hints = typing.get_type_hints(_typecheckingstub__276e14ede93619c8496d33625e8b9426df9db19c536b76f6785db1fff0434a40)
             check_type(argname="argument subnets", value=subnets, expected_type=type_hints["subnets"])
             check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
+            check_type(argname="argument nat_eip_allocation_ids", value=nat_eip_allocation_ids, expected_type=type_hints["nat_eip_allocation_ids"])
             check_type(argname="argument peering_configs", value=peering_configs, expected_type=type_hints["peering_configs"])
         self._values: typing.Dict[builtins.str, typing.Any] = {
             "subnets": subnets,
             "vpc": vpc,
         }
+        if nat_eip_allocation_ids is not None:
+            self._values["nat_eip_allocation_ids"] = nat_eip_allocation_ids
         if peering_configs is not None:
             self._values["peering_configs"] = peering_configs
 
@@ -729,6 +742,11 @@ class VPCProps:
         assert result is not None, "Required property 'vpc' is missing"
         return typing.cast(_aws_cdk_aws_ec2_ceddda9d.VpcProps, result)
 
+    @builtins.property
+    def nat_eip_allocation_ids(self) -> typing.Optional[typing.List[builtins.str]]:
+        result = self._values.get("nat_eip_allocation_ids")
+        return typing.cast(typing.Optional[typing.List[builtins.str]], result)
+
     @builtins.property
     def peering_configs(
         self,
@@ -778,6 +796,7 @@ def _typecheckingstub__df3f88ed1cc891dbd636f210624927d010c33ac961e6f577806e2dd93
     *,
     subnets: typing.Sequence[ISubnetsProps],
     vpc: typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]],
+    nat_eip_allocation_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
     peering_configs: typing.Optional[typing.Mapping[builtins.str, typing.Union[PeeringConfig, typing.Dict[builtins.str, typing.Any]]]] = None,
 ) -> None:
     """Type checking stubs"""
@@ -831,6 +850,7 @@ def _typecheckingstub__276e14ede93619c8496d33625e8b9426df9db19c536b76f6785db1fff
     *,
     subnets: typing.Sequence[ISubnetsProps],
     vpc: typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]],
+    nat_eip_allocation_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
     peering_configs: typing.Optional[typing.Mapping[builtins.str, typing.Union[PeeringConfig, typing.Dict[builtins.str, typing.Any]]]] = None,
 ) -> None:
     """Type checking stubs"""
